function ModelFiles = RemoveFromModelFiles(ModelFiles,RemoveModelFile)
% RemoveFromModelFiles: removes a specified row from a string matrix.
%
% USAGE:
%
%       ModelFiles = RemoveFromModelFiles(ModelFiles,RemoveModelFile)
%
% REQUIRED INPUT:  ModelFiles (string matrix)
%
%                  RemoveModelFile (string vector) that should be removed from
%                                  ModelFiles.
%
% REQUIRED OUTPUT: ModelFiles (string matrix)
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/EMO
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2008 European Central Bank.
%
%                       First version: Januart 25, 2007.
%                        This version: December 19, 2008.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 13-11-2007: Updated the documentation.
%
% * 23-5-2008:  Updated the documentation.
%
% * 19-12-2008: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

if size(ModelFiles,1)==1;
   if strcmp(lower(StringTrim(ModelFiles)),lower(StringTrim(RemoveModelFile)))==1;
      ModelFiles = '';
   end;
   return;
end;
%
% we need to create a new output string matrix
%
NewModelFiles = '';
for i=1:size(ModelFiles,1);
   if strcmp(lower(StringTrim(ModelFiles(i,:))),lower(StringTrim(RemoveModelFile)))==0;
       NewModelFiles = strvcat(NewModelFiles,StringTrim(ModelFiles(i,:)));
   end;
end;
ModelFiles = NewModelFiles;

%
% end of RemoveFromModelFiles.m
%
